==> haskell-these-1.1.1.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 these
version:              1.1.1.1
visibility:           public
id:                   these-1.1.1.1-FsDeeO6vOOR8E7ODQDD6EY
key:                  these-1.1.1.1-FsDeeO6vOOR8E7ODQDD6EY
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/isomorphism/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  ccbfc8bd78eb6ce9f41f2d0653a3c759
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-8.10.4/site-local/these-1.1.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/these-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/these-1.1.1.1
hs-libraries:         HSthese-1.1.1.1-FsDeeO6vOOR8E7ODQDD6EY
depends:
    assoc-1.0.2-I7DcKIGSqj45TFprKx6yDI base-4.14.1.0 binary-0.8.8.0
    deepseq-1.4.4.0 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-these-1.1.1.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 these
version:              1.1.1.1
visibility:           public
id:                   these-1.1.1.1-DLvQjLHOaSLCm6sqxL9SpS
key:                  these-1.1.1.1-DLvQjLHOaSLCm6sqxL9SpS
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/isomorphism/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  6c6a498fc6963ab3648399451e9dbfd3
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-8.10.4/site-local/these-1.1.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/these-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/these-1.1.1.1
hs-libraries:         HSthese-1.1.1.1-DLvQjLHOaSLCm6sqxL9SpS
depends:
    assoc-1.0.2-CoQFAW0XyBq50q0KVSKcjU base-4.14.1.0 binary-0.8.8.0
    deepseq-1.4.4.0 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
